@@ -13,18 +13,27 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #import "GdkQuartzView.h"
-#include "gdkwindow-quartz.h"
+#include "gdkquartzwindow.h"
 #include "gdkprivate-quartz.h"
+#include "gdkquartz.h"
 
 @implementation GdkQuartzView
 
+-(void)dealloc
+{
+  if (trackingRect)
+    {
+      [self removeTrackingRect:trackingRect];
+      trackingRect = 0;
+    }
+
+  [super dealloc];
+}
+
 -(void)setGdkWindow:(GdkWindow *)window
 {
   gdk_window = window;
@@ -50,71 +59,72 @@
   if (GDK_WINDOW_DESTROYED (gdk_window))
     return YES;
 
-  /* A view is opaque if its GdkWindow doesn't have the RGBA colormap */
-  return gdk_drawable_get_colormap (gdk_window) != gdk_screen_get_rgba_colormap (_gdk_screen);
+  /* A view is opaque if its GdkWindow doesn't have the RGBA visual */
+  return gdk_window_get_visual (gdk_window) != gdk_screen_get_rgba_visual (_gdk_screen);
 }
 
 -(void)drawRect:(NSRect)rect 
 {
   GdkRectangle gdk_rect;
-  GdkWindowObject *private = GDK_WINDOW_OBJECT (gdk_window);
-  GdkWindowImplQuartz *impl = GDK_WINDOW_IMPL_QUARTZ (private->impl);
+  GdkWindowImplQuartz *impl = GDK_WINDOW_IMPL_QUARTZ (gdk_window->impl);
   const NSRect *drawn_rects;
   NSInteger count;
   int i;
-  GdkRegion *region;
+  cairo_region_t *region;
 
   if (GDK_WINDOW_DESTROYED (gdk_window))
     return;
 
-  if (!(private->event_mask & GDK_EXPOSURE_MASK))
+  if (!(gdk_window->event_mask & GDK_EXPOSURE_MASK))
     return;
 
   if (NSEqualRects (rect, NSZeroRect))
     return;
 
+  if (!GDK_WINDOW_IS_MAPPED (gdk_window))
+    {
+      /* If the window is not yet mapped, clip_region_with_children
+       * will be empty causing the usual code below to draw nothing.
+       * To not see garbage on the screen, we draw an aesthetic color
+       * here. The garbage would be visible if any widget enabled
+       * the NSView's CALayer in order to add sublayers for custom
+       * native rendering.
+       */
+      [NSGraphicsContext saveGraphicsState];
+
+      [[NSColor windowBackgroundColor] setFill];
+      [NSBezierPath fillRect:rect];
+
+      [NSGraphicsContext restoreGraphicsState];
+
+      return;
+    }
+
   /* Clear our own bookkeeping of regions that need display */
   if (impl->needs_display_region)
     {
-      gdk_region_destroy (impl->needs_display_region);
+      cairo_region_destroy (impl->needs_display_region);
       impl->needs_display_region = NULL;
     }
 
   [self getRectsBeingDrawn:&drawn_rects count:&count];
-
-  /* Note: arbitrary limit here to not degrade performace too much. It would
-   * be better to optimize the construction of the region below, by using
-   * _gdk_region_new_from_yxbanded_rects.
-   */
-  if (count > 25)
+  region = cairo_region_create ();
+  
+  for (i = 0; i < count; i++)
     {
-      gdk_rect.x = rect.origin.x;
-      gdk_rect.y = rect.origin.y;
-      gdk_rect.width = rect.size.width;
-      gdk_rect.height = rect.size.height;
+      gdk_rect.x = drawn_rects[i].origin.x;
+      gdk_rect.y = drawn_rects[i].origin.y;
+      gdk_rect.width = drawn_rects[i].size.width;
+      gdk_rect.height = drawn_rects[i].size.height;
 
-      region = gdk_region_rectangle (&gdk_rect);
-    }
-  else
-    {
-      region = gdk_region_new ();
-
-      for (i = 0; i < count; i++)
-        {
-          gdk_rect.x = drawn_rects[i].origin.x;
-          gdk_rect.y = drawn_rects[i].origin.y;
-          gdk_rect.width = drawn_rects[i].size.width;
-          gdk_rect.height = drawn_rects[i].size.height;
-
-          gdk_region_union_with_rect (region, &gdk_rect);
-        }
+      cairo_region_union_rectangle (region, &gdk_rect);
     }
 
   impl->in_paint_rect_count++;
   _gdk_window_process_updates_recurse (gdk_window, region);
   impl->in_paint_rect_count--;
 
-  gdk_region_destroy (region);
+  cairo_region_destroy (region);
 
   if (needsInvalidateShadow)
     {
@@ -133,8 +143,7 @@
  */
 -(void)updateTrackingRect
 {
-  GdkWindowObject *private = GDK_WINDOW_OBJECT (gdk_window);
-  GdkWindowImplQuartz *impl = GDK_WINDOW_IMPL_QUARTZ (private->impl);
+  GdkWindowImplQuartz *impl = GDK_WINDOW_IMPL_QUARTZ (gdk_window->impl);
   NSRect rect;
 
   if (!impl->toplevel)
@@ -158,6 +167,15 @@
                                  owner:self
                               userData:nil
                           assumeInside:NO];
+
+  if (NSPointInRect ([[self window] convertScreenToBase:[NSEvent mouseLocation]], rect))
+    {
+      /* When a new window (and thus view) has been created, and the mouse
+       * is in the window area, we will not receive an NSMouseEntered
+       * event.  Therefore, we synthesize an enter notify event manually.
+       */
+      _gdk_quartz_events_send_enter_notify_event (gdk_window);
+    }
 }
 
 -(void)viewDidMoveToWindow
