@@ -1,4 +1,4 @@
-/* GTK+ - accessibility implementations
+/* GAIL - The GNOME Accessibility Implementation Library
  * Copyright 2001, 2002, 2003 Sun Microsystems Inc.
  *
  * This library is free software; you can redistribute it and/or
@@ -15,19 +15,14 @@
  * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "config.h"
-
-#include <glib/gi18n-lib.h>
 #include <string.h>
 #include <gtk/gtk.h>
 #include "gtkmenuitemaccessible.h"
-#include "gtkwidgetaccessibleprivate.h"
 #include "gtk/gtkmenuitemprivate.h"
 
 struct _GtkMenuItemAccessiblePrivate
 {
   gchar *text;
-  gboolean selected;
 };
 
 #define KEYBINDING_SEPARATOR ";"
@@ -46,8 +41,7 @@ static gint menu_item_remove_gtk (GtkContainer   *container,
 static void atk_action_interface_init    (AtkActionIface *iface);
 static void atk_selection_interface_init (AtkSelectionIface *iface);
 
-G_DEFINE_TYPE_WITH_CODE (GtkMenuItemAccessible, gtk_menu_item_accessible, GTK_TYPE_CONTAINER_ACCESSIBLE,
-                         G_ADD_PRIVATE (GtkMenuItemAccessible)
+G_DEFINE_TYPE_WITH_CODE (GtkMenuItemAccessible, _gtk_menu_item_accessible, GTK_TYPE_CONTAINER_ACCESSIBLE,
                          G_IMPLEMENT_INTERFACE (ATK_TYPE_ACTION, atk_action_interface_init);
                          G_IMPLEMENT_INTERFACE (ATK_TYPE_SELECTION, atk_selection_interface_init))
 
@@ -59,7 +53,7 @@ gtk_menu_item_accessible_initialize (AtkObject *obj,
   GtkWidget *parent;
   GtkWidget *menu;
 
-  ATK_OBJECT_CLASS (gtk_menu_item_accessible_parent_class)->initialize (obj, data);
+  ATK_OBJECT_CLASS (_gtk_menu_item_accessible_parent_class)->initialize (obj, data);
 
   g_signal_connect (data, "select", G_CALLBACK (menu_item_select), NULL);
   g_signal_connect (data, "deselect", G_CALLBACK (menu_item_deselect), NULL);
@@ -151,11 +145,7 @@ gtk_menu_item_accessible_ref_state_set (AtkObject *obj)
   AtkObject *menu_item;
   AtkStateSet *state_set, *parent_state_set;
 
-  state_set = ATK_OBJECT_CLASS (gtk_menu_item_accessible_parent_class)->ref_state_set (obj);
-
-  atk_state_set_add_state (state_set, ATK_STATE_SELECTABLE);
-  if (GTK_MENU_ITEM_ACCESSIBLE (obj)->priv->selected)
-    atk_state_set_add_state (state_set, ATK_STATE_SELECTED);
+  state_set = ATK_OBJECT_CLASS (_gtk_menu_item_accessible_parent_class)->ref_state_set (obj);
 
   menu_item = atk_object_get_parent (obj);
 
@@ -186,7 +176,7 @@ gtk_menu_item_accessible_get_role (AtkObject *obj)
       gtk_menu_item_get_submenu (GTK_MENU_ITEM (widget)))
     return ATK_ROLE_MENU;
 
-  return ATK_OBJECT_CLASS (gtk_menu_item_accessible_parent_class)->get_role (obj);
+  return ATK_OBJECT_CLASS (_gtk_menu_item_accessible_parent_class)->get_role (obj);
 }
 
 static const gchar *
@@ -201,7 +191,7 @@ gtk_menu_item_accessible_get_name (AtkObject *obj)
   if (widget == NULL)
     return NULL;
 
-  name = ATK_OBJECT_CLASS (gtk_menu_item_accessible_parent_class)->get_name (obj);
+  name = ATK_OBJECT_CLASS (_gtk_menu_item_accessible_parent_class)->get_name (obj);
   if (name)
     return name;
 
@@ -221,7 +211,7 @@ gtk_menu_item_accessible_finalize (GObject *object)
 
   g_free (accessible->priv->text);
 
-  G_OBJECT_CLASS (gtk_menu_item_accessible_parent_class)->finalize (object);
+  G_OBJECT_CLASS (_gtk_menu_item_accessible_parent_class)->finalize (object);
 }
 
 static void
@@ -239,11 +229,11 @@ gtk_menu_item_accessible_notify_gtk (GObject    *obj,
       g_signal_emit_by_name (atk_obj, "visible-data-changed");
     }
   else
-    GTK_WIDGET_ACCESSIBLE_CLASS (gtk_menu_item_accessible_parent_class)->notify_gtk (obj, pspec);
+    GTK_WIDGET_ACCESSIBLE_CLASS (_gtk_menu_item_accessible_parent_class)->notify_gtk (obj, pspec);
 }
 
 static void
-gtk_menu_item_accessible_class_init (GtkMenuItemAccessibleClass *klass)
+_gtk_menu_item_accessible_class_init (GtkMenuItemAccessibleClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
   AtkObjectClass *class = ATK_OBJECT_CLASS (klass);
@@ -259,12 +249,16 @@ gtk_menu_item_accessible_class_init (GtkMenuItemAccessibleClass *klass)
   class->initialize = gtk_menu_item_accessible_initialize;
   class->get_name = gtk_menu_item_accessible_get_name;
   class->get_role = gtk_menu_item_accessible_get_role;
+
+  g_type_class_add_private (klass, sizeof (GtkMenuItemAccessiblePrivate));
 }
 
 static void
-gtk_menu_item_accessible_init (GtkMenuItemAccessible *menu_item)
+_gtk_menu_item_accessible_init (GtkMenuItemAccessible *menu_item)
 {
-  menu_item->priv = gtk_menu_item_accessible_get_instance_private (menu_item);
+  menu_item->priv = G_TYPE_INSTANCE_GET_PRIVATE (menu_item,
+                                                 GTK_TYPE_MENU_ITEM_ACCESSIBLE,
+                                                 GtkMenuItemAccessiblePrivate);
 }
 
 static GtkWidget *
@@ -420,27 +414,10 @@ static const gchar *
 gtk_menu_item_accessible_action_get_name (AtkAction *action,
                                           gint       i)
 {
-  if (i == 0 && gtk_menu_item_accessible_get_n_actions (action) > 0)
-    return "click";
-  return NULL;
-}
+  if (i != 0 || gtk_menu_item_accessible_get_n_actions (action) == 0)
+    return NULL;
 
-static const gchar *
-gtk_menu_item_accessible_action_get_localized_name (AtkAction *action,
-                                                    gint       i)
-{
-  if (i == 0 && gtk_menu_item_accessible_get_n_actions (action) > 0)
-    return C_("Action name", "Click");
-  return NULL;
-}
-
-static const gchar *
-gtk_menu_item_accessible_action_get_description (AtkAction *action,
-                                                 gint       i)
-{
-  if (i == 0 && gtk_menu_item_accessible_get_n_actions (action) > 0)
-    return C_("Action description", "Clicks the menuitem");
-  return NULL;
+  return "click";
 }
 
 static gboolean
@@ -632,8 +609,6 @@ atk_action_interface_init (AtkActionIface *iface)
   iface->do_action = gtk_menu_item_accessible_do_action;
   iface->get_n_actions = gtk_menu_item_accessible_get_n_actions;
   iface->get_name = gtk_menu_item_accessible_action_get_name;
-  iface->get_localized_name = gtk_menu_item_accessible_action_get_localized_name;
-  iface->get_description = gtk_menu_item_accessible_action_get_description;
   iface->get_keybinding = gtk_menu_item_accessible_get_keybinding;
 }
 
@@ -645,7 +620,6 @@ menu_item_selection (GtkMenuItem  *item,
   gint i;
 
   obj = gtk_widget_get_accessible (GTK_WIDGET (item));
-  GTK_MENU_ITEM_ACCESSIBLE (obj)->priv->selected = selected;
   atk_object_notify_state_change (obj, ATK_STATE_SELECTED, selected);
 
   for (i = 0; i < atk_object_get_n_accessible_children (obj); i++)
@@ -853,7 +827,7 @@ menu_item_add_gtk (GtkContainer *container,
   parent_widget = gtk_menu_get_attach_widget (GTK_MENU (container));
   if (GTK_IS_MENU_ITEM (parent_widget))
     {
-      GTK_CONTAINER_ACCESSIBLE_CLASS (gtk_menu_item_accessible_parent_class)->add_gtk (container, widget, gtk_widget_get_accessible (parent_widget));
+      GTK_CONTAINER_ACCESSIBLE_CLASS (_gtk_menu_item_accessible_parent_class)->add_gtk (container, widget, gtk_widget_get_accessible (parent_widget));
 
     }
   return 1;
@@ -870,7 +844,7 @@ menu_item_remove_gtk (GtkContainer *container,
   parent_widget = gtk_menu_get_attach_widget (GTK_MENU (container));
   if (GTK_IS_MENU_ITEM (parent_widget))
     {
-      GTK_CONTAINER_ACCESSIBLE_CLASS (gtk_menu_item_accessible_parent_class)->remove_gtk (container, widget, gtk_widget_get_accessible (parent_widget));
+      GTK_CONTAINER_ACCESSIBLE_CLASS (_gtk_menu_item_accessible_parent_class)->remove_gtk (container, widget, gtk_widget_get_accessible (parent_widget));
     }
   return 1;
 }
